|Stars| |PyPI| |PyPIDownloadsTotal| |PyPIDownloadsMonth| |Conda| |Docs| |Build Status| |Coverage|

.. |Stars| image:: https://img.shields.io/github/stars/theislab/anndata?logo=GitHub&color=yellow
   :target: https://github.com/theislab/anndata/stargazers
.. |PyPI| image:: https://img.shields.io/pypi/v/anndata.svg
   :target: https://pypi.org/project/anndata
.. |PyPIDownloadsTotal| image:: https://pepy.tech/badge/anndata
   :target: https://pepy.tech/project/anndata
.. |PyPIDownloadsMonth| image:: https://img.shields.io/pypi/dm/scanpy?logo=PyPI&color=blue
   :target: https://pypi.org/project/anndata
.. |Conda| image:: https://img.shields.io/conda/vn/conda-forge/anndata.svg
   :target: https://anaconda.org/conda-forge/anndata
.. |Docs| image:: https://readthedocs.com/projects/icb-anndata/badge/?version=latest
   :target: https://anndata.readthedocs.io
.. |Build Status| image:: https://dev.azure.com/theislab/anndata/_apis/build/status/theislab.anndata?branchName=master
   :target: https://dev.azure.com/theislab/anndata/_build
.. |Coverage| image:: https://codecov.io/gh/theislab/anndata/branch/master/graph/badge.svg?token=IN1mJN1Wi8
   :target: https://codecov.io/gh/theislab/anndata


anndata - Annotated data
========================

anndata is a Python package for handling annotated data matrices in memory and on disk, positioned between pandas and xarray. anndata offers a broad range of computationally efficient features including, among others, sparse data support, lazy operations, and a PyTorch interface.

* Read the `documentation <https://anndata.readthedocs.io>`_.
* Ask questions on the `scverse Discourse <https://discourse.scverse.org>`_.
* Install via ``pip install anndata`` or ``conda install anndata -c conda-forge``.

.. would be nice to have the schema also on GitHub, but it’s much too wide there, hence need to duplicate description
.. GitHub doesn’t plan to resolve scaling images: https://github.com/github/markup/issues/295
